@@ -1,8 +1,6 @@
 #include <RcppArmadillo.h>
 using namespace Rcpp;
 using namespace arma;
-
-
 // [[Rcpp::depends(RcppArmadillo)]]
 // [[Rcpp::export]]
 double Chaipitak2013poolStat(List x) {
@@ -18,14 +16,16 @@ double Chaipitak2013poolStat(List x) {
 
  for(int i = 0; i < len; ++i){
     arma::mat mats = x[i];
-    int ns = mats.n_rows;
-    int ps = mats.n_cols;
+    double ns = mats.n_rows;
+    double ps = mats.n_cols;
     arma::mat covar = cov(mats);
+    double cov2trace = trace(covar * covar);
+    double covtrace = trace(covar);
 
 
     a2i[i] = pow(ns - 1.0, 2.0) /
       ps * (ns - 2.0) * (ns + 1.0) *
-      (trace(covar * covar) - (1.0 / (ns - 1.0))) * pow(trace(covar), 2.0);
+      (cov2trace - (1.0 / (ns - 1.0))) * pow(covtrace, 2.0);
 
     ntot += ns - 1.0;
     Apool += covar * (ns - 1.0);
@@ -34,10 +34,14 @@ double Chaipitak2013poolStat(List x) {
   }
 
   arma::mat pooledCov = Apool / ntot;
+  double pooledcov2trace = trace(pooledCov * pooledCov);
+  double pooledcovtrace = trace(pooledCov);
+  double pooledcov4trace = trace(pooledCov * pooledCov * pooledCov * pooledCov);
+  double pooledcov3trace = trace(pooledCov * pooledCov * pooledCov);
   double a2 = pow(ntot, 2.0) *
                pow(p * (ntot - 1.0) * (ntot + 2.0), -1.0) *
-    (trace(pooledCov * pooledCov) - pow(ntot, -1.0) *
-    pow(trace(pooledCov), 2.0));
+    (pooledcov2trace - pow(ntot, -1.0) *
+    pow(pooledcovtrace, 2.0));
 
   double f = - 4.0 / ntot;
   double c = - (2.0 * pow(ntot, 2.0) + 3.0 * ntot - 6.0) * pow(ntot * (pow(ntot, 2.0) + ntot + 2.0), -1.0);
@@ -49,11 +53,11 @@ double Chaipitak2013poolStat(List x) {
     (ntot - 2.0) * (ntot - 3.0), -1.0);
 
   double a4star = tau * pow(p, -1.0) *
-    (trace(pooledCov * pooledCov * pooledCov * pooledCov) +
-    f * trace(pooledCov * pooledCov * pooledCov) * trace(pooledCov) +
-    c * pow(trace(pooledCov * pooledCov), 2.0) +
-    d * trace(pooledCov * pooledCov) * pow(trace(pooledCov), 2.0) +
-    e * pow(trace(pooledCov), 4.0));
+    (pooledcov4trace +
+    f * pooledcov3trace * pooledcovtrace +
+    c * pow(pooledcov2trace, 2.0) +
+    d * pooledcov2trace * pow(pooledcovtrace, 2.0) +
+    e * pow(pooledcovtrace, 4.0));
 
   double delta2 = 4.0 * ((2.0 * a4star * ninv) * pow(pow(a2, 2.0) * p, -1.0) + ninv2);
 
@@ -80,13 +84,17 @@ double Chaipitak2013Stat(List x) {
 
   for(int i = 0; i < len; ++i){
     arma::mat mats = x[i];
-    int ns = mats.n_rows;
-    int ps = mats.n_cols;
+    double ns = mats.n_rows;
+    double ps = mats.n_cols;
     arma::mat covar = cov(mats);
 
-    a2i[i] = pow(ns - 1.0, 2.0) *
-      pow(ps * (ns - 2.0) * (ns + 1.0), -1.0) *
-      (trace(covar * covar) - pow(ns - 1.0, -1.0) * pow(trace(covar), 2.0));
+    double cov2trace = trace(covar * covar);
+    double covtrace = trace(covar);
+    
+    
+    a2i[i] = pow(ns - 1.0, 2.0) /
+      ps * (ns - 2.0) * (ns + 1.0) *
+        (cov2trace - (1.0 / (ns - 1.0))) * pow(covtrace, 2.0);
 
     ntot += ns - 1.0;
     Apool += covar * (ns - 1.0);
@@ -95,10 +103,14 @@ double Chaipitak2013Stat(List x) {
   }
 
   arma::mat pooledCov = Apool / ntot;
+  double pooledcov2trace = trace(pooledCov * pooledCov);
+  double pooledcovtrace = trace(pooledCov);
+  double pooledcov4trace = trace(pooledCov * pooledCov * pooledCov * pooledCov);
+  double pooledcov3trace = trace(pooledCov * pooledCov * pooledCov);
   double a2 = pow(ntot, 2.0) *
     pow(p * (ntot - 1.0) * (ntot + 2.0), -1.0) *
-    (trace(pooledCov * pooledCov) - pow(ntot, -1.0) *
-    pow(trace(pooledCov), 2.0));
+    (pooledcov2trace - pow(ntot, -1.0) *
+    pow(pooledcovtrace, 2.0));
 
   double f = - 4.0 * pow(ntot, -1.0);
   double c = - (2.0 * pow(ntot, 2.0) + 3.0 * ntot - 6.0) * pow(ntot * (pow(ntot, 2.0) + ntot + 2.0), -1.0);
@@ -110,11 +122,11 @@ double Chaipitak2013Stat(List x) {
     (ntot - 2.0) * (ntot - 3.0), -1.0);
 
   double a4star = tau * pow(p, -1.0) *
-    (trace(pooledCov * pooledCov * pooledCov * pooledCov) +
-    f * trace(pooledCov * pooledCov * pooledCov) * trace(pooledCov) +
-    c * pow(trace(pooledCov * pooledCov), 2.0) +
-    d * trace(pooledCov * pooledCov) * pow(trace(pooledCov), 2.0) +
-    e * pow(trace(pooledCov), 4.0));
+    (pooledcov4trace +
+    f * pooledcov3trace * pooledcovtrace +
+    c * pow(pooledcov2trace, 2.0) +
+    d * pooledcov2trace * pow(pooledcovtrace, 2.0) +
+    e * pow(pooledcovtrace, 4.0));
 
   double delta2 = 4.0 * ((2.0 * a4star * ninv) * pow(pow(a2, 2.0) * p, -1.0) + ninv2);
 
